@@ -5,19 +5,21 @@ fn case(string: &str) -> Option<Case> {
         "pascal" => Case::PascalCase,
         "camel" => Case::CamelCase,
         "snake" => Case::SnakeCase,
+        "sentence" => Case::Sentence,
         _ => return None,
     })
 }
 
 const HELP: &'static str = r"Usage: caser CASE term [terms]
 
-Where CASE is one of pascal, camel, or snake.
+Where `CASE` is one of pascal, camel, snake, or sentence.
 
 For reference:
 
 ThisIsPascalCase
 thisIsCamelCase
 this_is_snake_case
+This is sentence case. It starts with a capital after each sentence-ending punctuation mark.
 
 Terms are converted and printed one per line.
 
